@@ -1,13 +1,9 @@
 package Yukki::Web::Plugin::SyntaxHighlight;
-$Yukki::Web::Plugin::SyntaxHighlight::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::SyntaxHighlight::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
-
-use Types::Standard qw( HashRef Str );
-
-use namespace::clean;
+BEGIN {
+  $Yukki::Web::Plugin::SyntaxHighlight::VERSION = '0.112770';
+}
+use v5.12;
+use Moose;
 
 extends 'Yukki::Web::Plugin';
 
@@ -15,12 +11,11 @@ extends 'Yukki::Web::Plugin';
 
 use Syntax::Highlight::Engine::Kate;
 use Syntax::Highlight::Engine::Kate::All;
-use Syntax::Highlight::Engine::Kate::Perl6;
 
 
 has format_helpers => (
     is          => 'ro',
-    isa         => HashRef[Str],
+    isa         => 'HashRef[Str]',
     required    => 1,
     default     => sub { +{
         'highlight'      => 'highlight_syntax',
@@ -39,13 +34,14 @@ sub highlight_syntax {
     my ($language, $text) = split /:/, $arg, 2;
 
     my $engine = Syntax::Highlight::Engine::Kate->new(
+        language => $language,
         substitutions => {
             "<"  => "&#x3c;",
             ">"  => "&#x3e;",
             "&"  => "&#x26;",
-            " "  => " ",
-            "\t" => " " x 4,
-            "\n" => "\n",
+            " "  => "&#xa0;",
+            "\t" => "&#xa0;&#xa0;&#xa0;&#xa0;",
+            "\n" => "<br/>\n",
         },
         format_table => {
             Alert        => [q[<span class="syntax-alert">],         q[</span>]],
@@ -63,7 +59,7 @@ sub highlight_syntax {
             Normal       => [q[],                                    q[]       ],
             Operator     => [q[<span class="syntax-operator">],      q[</span>]],
             Others       => [q[<span class="syntax-others">],        q[</span>]],
-            RegionMarker => [q[<span class="syntax-region-marker">], q[</span>]],
+            RegionMarker => [q[<span class="syntax-region-marker">], q[</span>]], 
             Reserved     => [q[<span class="syntax-reserved">],      q[</span>]],
             String       => [q[<span class="syntax-string">],        q[</span>]],
             Variable     => [q[<span class="syntax-variable">],      q[</span>]],
@@ -71,46 +67,39 @@ sub highlight_syntax {
         },
     );
 
-    # HACK BECAUSE KATE HIGHLIGHTER SUCKS
-    $engine->{'syntaxes'}{'Perl6'} = 'Perl6';
-
-    $engine->language($language);
-
     my $highlighted_text = $engine->highlightText($text);
 
     if ($params->{helper_name} =~ /highlight-(div|span)/) {
         my $element = $1;
-        $element = 'pre' if $element eq 'div';
-        $highlighted_text
+        $highlighted_text 
             = qq[<$element class="syntax-highlight language-$language">]
             . $engine->highlightText($text)
             . qq[</$element>];
     }
 
+    warn "$highlighted_text\n";
+
     return $highlighted_text;
 }
 
-1;
+__PACKAGE__->meta->make_immutable;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin::SyntaxHighlight - add syntax highlighting to wiki pages
 
 =head1 VERSION
 
-version 0.991_007
+version 0.112770
 
 =head1 SYNOPSIS
 
   <div>{{highlight:Perl:
   use v5.14;
-  use Moo;
+  use Moose;
 
   has something => ( is => 'ro' );
   }}</div>
@@ -119,7 +108,7 @@ version 0.991_007
 
   {{highlight-div:Perl:
   use v5.14;
-  use Moo;
+  use Moose;
 
   has something => ( is => 'ro' );
   }}
@@ -160,9 +149,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
